@@ -1,9 +1,11 @@
-import pandas as pd
 from datetime import datetime
 from functools import reduce
+
+import dask
+import pandas as pd
+
 from commodutil import dates
 from commodutil import pandasutil
-import dask
 
 
 def seasonailse(df, fillna=True):
@@ -13,10 +15,22 @@ def seasonailse(df, fillna=True):
     assert isinstance(df, pd.Series)
 
     s = df[~((df.index.month == 2) & (df.index.day == 29))]  # remove leap dates 29 Feb
-    seas = s.groupby([s.index.month, s.index.day, s.index.year, ]).mean().unstack()
+    seas = (
+        s.groupby(
+            [
+                s.index.month,
+                s.index.day,
+                s.index.year,
+            ]
+        )
+        .mean()
+        .unstack()
+    )
 
     # replace index with dates from current year
-    newind = [pd.to_datetime('{}-{}-{}'.format(dates.curyear, i[0], i[1])) for i in seas.index]
+    newind = [
+        pd.to_datetime("{}-{}-{}".format(dates.curyear, i[0], i[1])) for i in seas.index
+    ]
     seas.index = newind
 
     if fillna:
@@ -25,7 +39,7 @@ def seasonailse(df, fillna=True):
     return seas
 
 
-def seasonalise_weekly(df, freq='W'):
+def seasonalise_weekly(df, freq="W"):
     """
     Edge case for handling weekly data - eg DOE where we need to tweak the standard
     seasonalise() method.
@@ -38,9 +52,14 @@ def seasonalise_weekly(df, freq='W'):
     df = pd.merge(df, df.index.isocalendar(), left_index=True, right_index=True)
     df = df.groupby([df.week, df.year]).mean()[df.columns[0]].unstack()
     # when converting back to date format, some years don't have week 53 so drop for now
-    if 53 in df.index and pd.to_datetime('%s-12-31' % dates.curyear).isocalendar()[1] == 52:
+    if (
+        53 in df.index
+        and pd.to_datetime("%s-12-31" % dates.curyear).isocalendar()[1] == 52
+    ):
         df = df.drop(53)
-    df.index = df.index.map(lambda x: datetime.fromisocalendar(2021, x, 1))
+    df.index = df.index.map(
+        lambda x: datetime.fromisocalendar(datetime.now().year, x, 1)
+    )
     return df
 
 
@@ -48,7 +67,7 @@ def forward_only(df):
     """
     Only take forward timeseries from cur month onwards (discarding the history)
     """
-    df = df[dates.curmonyear_str:]
+    df = df[dates.curmonyear_str :]
     return df
 
 
@@ -56,7 +75,7 @@ def format_fwd(df, last_index=None):
     """
     Format a monthly-frequency forward curve into a daily series
     """
-    df = df.resample('D').mean().fillna(method='ffill')
+    df = df.resample("D").mean().fillna(method="ffill")
     if last_index is not None:
         df = df[last_index:]
 
@@ -92,9 +111,16 @@ def reindex_year(df):
     dfs = dask.compute(*dfs)
     dfs = [x for x in dfs if x is not None]
     # merge all series into one dataframe, concat doesn't quite do the job
-    res = reduce(lambda left, right: pd.merge(left, right, left_index=True, right_index=True, how='outer'),dfs)
-    res = res.dropna(how='all') # drop uneeded columns out into future
-    res = pandasutil.fillna_downbet(res) # use this as above ffills incorrectly at end of timeseries
+    res = reduce(
+        lambda left, right: pd.merge(
+            left, right, left_index=True, right_index=True, how="outer"
+        ),
+        dfs,
+    )
+    res = res.dropna(how="all")  # drop uneeded columns out into future
+    res = pandasutil.fillna_downbet(
+        res
+    )  # use this as above ffills incorrectly at end of timeseries
 
     return res
 
@@ -109,10 +135,14 @@ def monthly_mean(df):
     :param df:
     :return:
     """
-    monthly_mean = df.groupby(pd.Grouper(freq='MS')).mean()
-    month_pivot = monthly_mean.groupby([monthly_mean.index.month, monthly_mean.index.year]).sum().unstack()
+    monthly_mean = df.groupby(pd.Grouper(freq="MS")).mean()
+    month_pivot = (
+        monthly_mean.groupby([monthly_mean.index.month, monthly_mean.index.year])
+        .sum()
+        .unstack()
+    )
     return month_pivot
 
 
-if __name__ == '__main__':
-    pass
\ No newline at end of file
+if __name__ == "__main__":
+    pass
